NestedBoxes Example
===============================================================================

:download:`nested_boxes.enaml <../../../examples/layout/advanced/nested_boxes.enaml>`

.. literalinclude:: ../../../examples/layout/advanced/nested_boxes.enaml
    :language: python

::

 $ enaml-run nested_boxes.enaml

.. image:: images/nested_boxes.png
